###############
Mapping Helpers
###############

Odin includes a few helpers to help defining mappings.

Defining Mappings
=================

When defining mappings using the shorthand mappings property these methods simplify the definition of mapping rules.
They also provide sensible defaults.

.. automodule:: odin.mapping

    .. autofunction:: define

    .. autofunction:: assign
